module Tropy
  ID_LENGTH = 10
  CONTENT_LENGTH = 400

  class Entry
    attr_accessor :id,:title,:content
    def initialize
      @id = nil
      @title = ''
      @content = ''
    end
  end

  class TropyController
    def initialize(dataPath)
      @dataPath = dataPath
    end

    def getEntry(id)
      unless idValid?(id)
        return nil
      end

      filename = getDataFileName(id)
      
      begin
        open(filename) do |file|
          entry = Entry.new
          entry.id = id

          unless file.eof
            entry.title = file.gets.chomp
          end

          file.each do |line|
            entry.content += line.chomp + "\n"
          end
          return entry
        end
      rescue Errno::ENOENT
        return nil
      end
    end

    def random
      dbfiles = Dir.glob(@dataPath + "/*.dat")
      if dbfiles.length == 0
        return appendEntry(emptyEntry)
      end

      dbfile = dbfiles[rand(dbfiles.length)]
      id = File.basename(dbfile, ".dat")

      return self.getEntry(id)
    end

     
    def appendEntry(inputData)
      id = getNewID
      writeEntry(id,inputData)
      return id

    end

    def updateEntry(id,inputData)
      unless idValid?(id)
        return nil
      end

      if File.exist?(getDataFileName(id)) 
        writeEntry(id,inputData)
        return id
      else
        deleteEntry(id)
        return nil
      end
    end

    private

    def idValid?(id)
      return (/^[a-zA-Z0-9]+$/ =~ id)
    end

    def getDataFileName(id)
      return @dataPath + "/" + id + ".dat"
    end
    
    def getNewID
      charArray = ("A".."Z").to_a + ("a".."z").to_a + ("0".."9").to_a
      loop do
        id = ""
        ID_LENGTH.times do
          id += charArray[rand(charArray.length)]
        end
        unless File.exist?(getDataFileName(id))
          return id
        end
      end
    end

    def emptyEntry
      c = "Tropy is Empty\nI'm hungry"
      return c
    end

    def writeEntry(id,inputData)
      filename = getDataFileName(id)
      open(filename, "w") do |file|
        file.write(inputData[0, CONTENT_LENGTH]) 
      end
    end

    def deleteEntry(id)
      filename = getDataFileName(id)
      if File.exist?(filename)
        File.delete(filename)
      end
    end
  end
end

















